package
Version:
v0.0.0-...-144d224
Opens a new window with list of versions in this module.
Published: Jun 11, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewCmdParse returns a cobra command for parsing terraform files
type Options struct {
InputType string
}
Options is a struct to support parse command
NewOptions returns initialized Options
Complete completes all the required options
Run executes parse command
Validate validates the provided options
Source Files
¶
Click to show internal directories.
Click to hide internal directories.